<template>
  <el-dialog title="先行登记证据保存审批表"
             :close-on-click-modal="false"
             :visible.sync="visible">
    <!--先行登记审批表-->
    <el-form ref="form" :model="form" label-width="140px" :disabled="form.registerState == '1'">
      <el-form-item label="申请事项">
        <el-input v-model="form.applyItem"></el-input>
      </el-form-item>
      <el-form-item label="案由">
        <el-input v-model="form.casePoint"></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="立案日期">
            <el-date-picker
                v-model="form.caseDate"
                type="date"
                placeholder="选择日期"
                style="width: 100%"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="当事人姓名(名称)">
            <el-input v-model="form.litigant"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="法定代表人(负责人)">
            <el-input v-model="form.legalPerson"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="证件名称">
            <el-select v-model="form.litigantCert" placeholder="请选择当事人证件类型" style="width: 100%"
                       :disabled="form.registerState == '1'">
              <el-option
                v-for="item in cardList"
                :key="item.value"
                :label="item.label"
                :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="证件号码">
            <el-input v-model="form.certNo"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="住址(地址)">
            <el-input v-model="form.address"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="电话">
            <el-input v-model="form.phone"></el-input>
          </el-form-item>
        </el-col>
      </el-row>

      <el-form-item label="简要案情及申请理由依据">
        <el-input type="textarea" v-model="form.caseReason"></el-input>
      </el-form-item>

      <public-opinion ref="publicOpinion" :registerState="form.registerState"></public-opinion>
      <WordView ref="wordInfo" :isShowYulan="showView" @cancel="cancelWord"></WordView>
    </el-form>
<!--    <div style="text-align: center">
      <el-button v-if="form.registerState != '1'" plain @click="onSubmit('0')">保存</el-button>
      <el-button v-if="form.registerState != '1'" type="warning" plain @click="onSubmit('1')">定稿</el-button>
      <el-button type="primary" plain @click="viewVord(form)">预览</el-button>
      <el-button type="success" plain @click="downloadWord(form)">下载</el-button>
    </div>-->
  </el-dialog>
</template>

<script>
import {getObj, saveObj} from '@/api/News/approvalFormForRegistration'
import publicOpinion from "@/views/News/publicOpinion"
import WordView from '@/views/News/word-view/index'
import moment from "moment";
import {remote} from "@/api/admin/dict";

export default {
  name: "xxdjbczj",
  props: ['isShowYulan', 'id', 'processId'],
  components: {
    // dict,
    publicOpinion,
    WordView
  },
  data() {
    return {
      showView: false,
      visible: false,
      cardList: [],
      form: {
        applyItem: '',//申请事项
        casePoint: '',//案由
        caseDate: '',//立案日期
        litigant: '',//姓名
        legalPerson: '',//法定代表人
        litigantCert: '',//证件类型
        address: '',
        phone: '',
        certNo: '',
        caseReason: '',
        registerState: ''
      }
    }
  },
  methods: {
    init(id) {
      remote('document_type').then(res => {
        this.cardList = res.data.data;
      })

      getObj(id).then((res) => {
        if (res.data.code == 0) {
          this.visible = true;
          let v = res.data.data;
          for (let attr in v) {
            if (attr != 'publicOpinion' && v[attr] == null) {
              v[attr] = "";
            }
          }
          this.form = v;
          //查询公共意见
          this.$nextTick(() => {
            this.$refs.publicOpinion.init(this.form.publicOpinion);
          })
        }
      })
    },
    onSubmit(type) {
      this.$refs['form'].validate((valid) => {
        if (valid) {
          let obj = this;
          if ("1" == type) {
            this.$confirm('保存为定稿将不能修改，是否继续？', '提示', {
              confirmButtonText: '是',
              cancelButtonText: '否',
              type: 'warning'
            }).then(function () {
              obj.submitLoading = true;
              obj.form.registerState = type;
              obj.form.registerId = obj.id;
              obj.form.publicOpinion = obj.$refs.publicOpinion.opinionForm;
              obj.form.processId = obj.processId;
              saveObj(obj.form).then((res) => {
                obj.submitLoading = false;
                if (res.data.code) {
                  obj.$message.success("操作成功");
                  obj.cancel();
                }
              })
            })
          } else {
            obj.submitLoading = true;
            obj.form.registerState = type;
            obj.form.registerId = obj.id;
            obj.form.publicOpinion = this.$refs.publicOpinion.opinionForm;
            obj.form.processId = this.processId;
            saveObj(obj.form).then((res) => {
              this.submitLoading = false;
              if (res.data.code == 0) {
                this.$message.success("操作成功");
                this.cancel();
              }
            })
          }
        }
      })
    },
    cancel() {
      this.$emit('cancel', false)
    },
    cancelWord() {
      this.showView = false;
    },
    viewVord(data) {
      //↓↓↓↓↓↓以下部分根据具体业务修改↓↓↓↓↓↓
      //格式转换
      let wordData = this.transforData(data);
      //↑↑↑↑↑↑以上部分根据具体业务修改↑↑↑↑↑↑
      this.showView = true;
      this.$nextTick(() => {
        this.$refs.wordInfo.init(wordData, "/wordes/xxdjbczjspb.docx");
      })
    },
    downloadWord(data) {
      let wordData = this.transforData(data);
      WordView.methods.exportDoc(wordData, "/wordes/xxdjbczjspb.docx", "先行登记保存证据审批表.docx");
    },
    transforData(obj) {
      let s = JSON.stringify(obj);
      let data = JSON.parse(s);
      if (data.caseDate != '' && data.caseDate != null) {
        data.caseDate = moment(data.caseDate).format('YYYY年MM月DD日');
      }
      let opinion = data.publicOpinion;
      for (let attr in opinion) {
        if (opinion[attr] == null) {
          data[attr] = '';
        } else {
          data[attr] = opinion[attr];
        }
      }
      let str = JSON.stringify(data);
      let jsonData = JSON.parse(str);
      data = jsonData;

      if (data.undertakeDate != '' && data.undertakeDate != null) {
        data.undertakeDate = moment(data.undertakeDate).format('YYYY年MM月DD日');
      } else {
        data.undertakeDate = '  年  月  日'
      }
      if (data.takeDate != '' && data.takeDate != null) {
        data.takeDate = moment(data.takeDate).format('YYYY年MM月DD日');
      } else {
        data.takeDate = '  年  月  日'
      }
      if (data.legalDate != '' && data.legalDate != null) {
        data.legalDate = moment(data.legalDate).format('YYYY年MM月DD日');
      } else {
        data.legalDate = '  年  月  日'
      }
      if (data.organDate != '' && data.organDate != null) {
        data.organDate = moment(data.organDate).format('YYYY年MM月DD日');
      } else {
        data.organDate = '  年  月  日'
      }
      data.opinion = opinion;
      return data;
    }
  }
}
</script>
